aboutsummaryrefslogtreecommitdiff
path: root/src/boot/me/transutil.ml
diff options
context:
space:
mode:
authorGraydon Hoare <[email protected]>2010-06-30 22:45:54 -0700
committerGraydon Hoare <[email protected]>2010-06-30 22:45:54 -0700
commit6a0b06e56287f1de7ff096ed79fbf86e1e527290 (patch)
tree5596e1e36c3f59dc7f25c84730705aaf28128a0b /src/boot/me/transutil.ml
parentNo more "transplant" behavior in "let @x = y", gotta box explicitly. (diff)
downloadrust-6a0b06e56287f1de7ff096ed79fbf86e1e527290.tar.xz
rust-6a0b06e56287f1de7ff096ed79fbf86e1e527290.zip
Rename 'exterior' to 'box' and 'interior' to 'local' (at least wrt. slots; keep MEM_interior for describing interior-parts-of-allocations)
Diffstat (limited to 'src/boot/me/transutil.ml')
-rw-r--r--src/boot/me/transutil.ml8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/boot/me/transutil.ml b/src/boot/me/transutil.ml
index 8c6b8bc3..d7fbb566 100644
--- a/src/boot/me/transutil.ml
+++ b/src/boot/me/transutil.ml
@@ -7,7 +7,7 @@ open Semant;;
* "simple" precise, mark-sweep, single-generation, per-task (thereby
* preemptable and relatively quick) GC scheme on mutable memory.
*
* - For the sake of this note, call any exterior of 'state' effect a gc_val.
*
* - gc_vals come from the same malloc as all other values but undergo
* different storage management.
@@ -19,7 +19,7 @@ open Semant;;
*
* - A pointer to a gc_val, however, points to the third of these three
* words. So a certain quantity of code can treat gc_vals the same way it
* would treat refcounted exterior vals.
*
* - The first word at the head of a gc_val is used as a refcount, as in
* non-gc allocations.
@@ -122,7 +122,7 @@ let rec ty_mem_ctrl (ty:Ast.ty) : mem_ctrl =
if type_has_state ty
then MEM_gc
else MEM_rc_opaque
- | Ast.TY_exterior t ->
+ | Ast.TY_box t ->
if type_has_state t
then MEM_gc
else
@@ -139,7 +139,7 @@ let rec ty_mem_ctrl (ty:Ast.ty) : mem_ctrl =
let slot_mem_ctrl (slot:Ast.slot) : mem_ctrl =
match slot.Ast.slot_mode with
Ast.MODE_alias -> MEM_interior
- | Ast.MODE_interior ->
+ | Ast.MODE_local ->
ty_mem_ctrl (slot_ty slot)
;;
@@ -7,7 +7,7 @@ open Semant;;
* preemptable and relatively quick) GC scheme on mutable memory.
*
- * - For the sake of this note, call any exterior of 'state' effect a gc_val.
+ * - For the sake of this note, call any box of 'state' effect a gc_val.
*
* - gc_vals come from the same malloc as all other values but undergo
@@ -19,7 +19,7 @@ open Semant;;
* - A pointer to a gc_val, however, points to the third of these three
* words. So a certain quantity of code can treat gc_vals the same way it
- * would treat refcounted exterior vals.
+ * would treat refcounted box vals.
*
* - The first word at the head of a gc_val is used as a refcount, as in